@@ -29,6 +29,6 @@ struct _EditorMainPageClass
 
 GtkType editor_main_page_get_type (void);
 
-GtkWidget* editor_main_page_new (MtmTheme *theme);
+GtkWidget* editor_main_page_new (MtmTheme *theme, GtkWidget *parent_window);
 
 #endif /* __EDITOR_MAIN_PAGE_H__ */
