@@ -29,8 +29,16 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <string.h>
+#if 0 /* xml-config , gnome-config --libs xml & pkg-config --libs xml are all broKEN
+	  * i sent a patch to the list xml@gnome.org for now deal with their brokenes
+	  * Chema
+	  */
 #include <gnome-xml/parser.h>
 #include <gnome-xml/xmlmemory.h>
+#else
+#include <parser.h>
+#include <xmlmemory.h>
+#endif
 
 #include <mtm/mtm-theme.h>
 #include <mtm/mtm-ext-handler.h>
